@@ -4,7 +4,6 @@ from ..models import QueueMessage
 from socket import gethostname
 from datetime import datetime
 import base64
-from otel_extensions import instrumented
 from typing import Optional
 
 __all__ = [
@@ -20,15 +19,15 @@ class OpenTelemetryDataProducer:
         self.__client.queue_declare(queue=self.queue_name, durable=True)
         self.producer_app_id = producer_app_id
 
-    @instrumented
-    def publish_telemetry_data(self, data_type: str, telemetry_data: bytes, compression: Optional[str] = None):
+    def publish_telemetry_data(
+        self, data_type: str, telemetry_data: bytes, compression: Optional[str] = None
+    ):
         base64_content = base64.b64encode(telemetry_data).decode("utf-8")
         payload = TelemetryData(dataType=data_type, base64ProtobufData=base64_content)
         if compression:
             payload.compression = compression
         self._publish_telemetry_data_payload(payload)
 
-    @instrumented
     def _publish_telemetry_data_payload(self, telemetry_payload: TelemetryData):
         queue_message = QueueMessage(
             payload=telemetry_payload,
