@@ -51,7 +51,7 @@ def cli(
     username: str,
     password: str,
     client_id: str,
-    retries: int = 3,
+    retries: int = 6,
 ):
     with setup_telemetry():
         if username is None or password is None:
@@ -69,12 +69,13 @@ def cli(
         total_attempts = retries + 1
         for try_index in range(total_attempts):
             try:
-                if try_index > 0:
+                if try_index == 0:
                     upload_artifact_direct(file_path, metadata_dict)
                 else:
                     upload_artifact_through_queue(
                         url, client_id, file_path, metadata_dict
                     )
+                sleep(3) # workaround to reduce load
                 break
             except Exception:
                 if (try_index + 1) >= total_attempts:
